@@ -102,9 +102,12 @@ class Solution:
         self.global_includes = []
         self.libs = []
         self.dylibs = []
+        self.userspace_libs = []
         self.libpath = []
-        self.dylibpath = []
+        self.dylib_path = []
+        self.userspace_lib_path = []
         self.depend_libs = []
+        self.depend_userspace_libs = []
         self.depend_dylibs = []
         self.org_defines = {}
         self.defines = {}
@@ -113,6 +116,7 @@ class Solution:
         self.CXXFLAGS = []
         self.LINKFLAGS = []
         self.SHLINKFLAGS = []
+        self.APPLINKFLAGS = []
         self.ICC_ASFLAGS = []
         self.ICC_CFLAGS = []
         self.ICC_CXXFLAGS = []
@@ -122,6 +126,7 @@ class Solution:
         self.ARMCC_CXXFLAGS = []
         self.ARMCC_LINKFLAGS = []
         self.ld_script = ''
+        self.uspace_app_ld_script = ''
         self.ld_script_component = None
         self.cpu_name = ''
         self.toolchain_prefix = ''
@@ -290,6 +295,9 @@ class Solution:
                         component.private_shldflag.append(c)
 
 
+            for component in self.components:
+                if component.type == 'userspace_common':
+                    add_defines(component)
             for component in self.components:
                 if component.type == 'kernel':
                     add_defines(component)
@@ -337,7 +345,10 @@ class Solution:
                     for c in component.build_config.shldflag.split():
                         if(check_duplicate_value(self.SHLINKFLAGS, c) == False):
                             self.SHLINKFLAGS.append(c)
-
+                    for c in component.build_config.appldflag.split():
+                        if(check_duplicate_value(self.APPLINKFLAGS, c) == False):
+                            self.APPLINKFLAGS.append(c)
+                    
                     for c in component.build_config.icc_cflag.split():
                         if(check_duplicate_value(self.ICC_CFLAGS, c) == False):
                             self.ICC_CFLAGS.append(c)
@@ -416,6 +427,8 @@ class Solution:
             self.libpath.append(self.lib_path)
             self.dylib_path = os.path.join(self.yoc_path, 'dylib')
             self.libpath.append(self.dylib_path)
+            self.userspace_lib_path = os.path.join(self.yoc_path, 'userspace_lib') 
+            self.libpath.append(self.userspace_lib_path)
             self.app_path = os.path.join(self.yoc_path, 'app')
             self.flash_program = solution_hw_info.flash_program
             self.program_data_files = solution_hw_info.program_data_files
@@ -426,7 +439,7 @@ class Solution:
 
             for component in self.components:
                 if (len(component.source_files) > 0 and component.name not in self.libs
-                    and component.type != "dynamic"):
+                    and component.type != "dynamic" and component.type != "userspace_common"):
                     self.libs.append(component.name)
                     # if component.name is start with lib, scons will not add prefix: lib
                     if component.name.startswith('lib'):
@@ -437,11 +450,20 @@ class Solution:
                             self.lib_path, 'lib' + component.name + '.a'))
 
                 component.variable_convert(self.variables)
-                if (len(component.source_files) > 0 and component.name not in self.libs
+                if (len(component.source_files) > 0 and component.name not in self.dylibs
                    and component.type == "dynamic" and component.name != "separate_app"):
                         self.dylibs.append(component.name)
                         self.depend_dylibs.append(os.path.join(self.dylib_path,
                                                 'lib' + component.name +'.dylib'))
+                if (len(component.source_files) > 0 and component.name not in self.userspace_libs
+                   and component.type == "userspace_common"):
+                    self.userspace_libs.append(component.name)
+                    if component.name.startswith('lib'):
+                        self.depend_userspace_libs.append(os.path.join(
+                            self.userspace_lib_path, component.name + '.a'))
+                    else:
+                        self.depend_userspace_libs.append(os.path.join(
+                            self.userspace_lib_path, 'lib' + component.name + '.a'))
 
                 # include
                 for path in component.build_config.include_updated:
@@ -462,7 +484,8 @@ class Solution:
             self.toolchain_path = solution_hw_info.toolchain_path
             self.ld_script = solution_hw_info.ld_script
             self.ld_script = self.variables.convert(self.ld_script)
-
+            self.uspace_app_ld_script = solution_hw_info.uspace_app_ld_script
+            self.uspace_app_ld_script = self.variables.convert(self.uspace_app_ld_script)
             if self.solution_component.hw_info.ld_script:
                 self.ld_script_component = self.solution_component
             elif self.board_component and self.board_component.hw_info.ld_script:
@@ -476,6 +499,9 @@ class Solution:
                 logger.error("not found LD script file, please set ld_script")
                 exit(-1)
 
+            for component in self.components:
+                if component.name == 'uspace_app':
+                    component.uspace_app_ld_script = self.uspace_app_ld_script
             # append variables to defines
             for k, v in self.variables.items():
                 if k.isupper():
